@@ -44,11 +44,11 @@
         stop("Non convenient xax")
     if (yax > x$nf) 
         stop("Non convenient yax")
-    def.par <- par(no.readonly = TRUE)
-    on.exit(par(def.par))
-    layout(matrix(c(1, 2, 3, 4, 4, 5, 4, 4, 6), 3, 3), 
+    def.par <- graphics::par(no.readonly = TRUE)
+    on.exit(graphics::par(def.par))
+    graphics::layout(matrix(c(1, 2, 3, 4, 4, 5, 4, 4, 6), 3, 3), 
         respect = TRUE)
-    par(mar = c(0.1, 0.1, 0.1, 0.1))
+    graphics::par(mar = c(0.1, 0.1, 0.1, 0.1))
     s.corcircle(x$as, xax, yax, sub = "Axis", csub = 2, 
         clabel = 1.25)
     s.arrow(x$c1, xax, yax, sub = "Variables", csub = 2, 
