@@ -11,17 +11,17 @@
     sqlw <- sqrt(dudi1$lw)
     sqcw <- sqrt(dudi1$cw)
        
-    fmla <- as.formula(paste("y ~", paste(names(df), collapse = "+")))
-    mf <- model.frame(fmla, data = cbind.data.frame(y, df))
+    fmla <- stats::as.formula(paste("y ~", paste(names(df), collapse = "+")))
+    mf <- stats::model.frame(fmla, data = cbind.data.frame(y, df))
     mt <- attr(mf, "terms")
-    x <- model.matrix(mt, mf)
+    x <- stats::model.matrix(mt, mf)
     wt <- outer(sqlw, sqcw)
     ## Fast function for computing sum of squares of the fitted table
-    obs <- sum((lm.wfit(y = y,x = x, w = dudi1$lw)$fitted.values * wt)^2) / inertot
+    obs <- sum((stats::lm.wfit(y = y,x = x, w = dudi1$lw)$fitted.values * wt)^2) / inertot
 
     isim <- rep(NA, nrepet)
     for(i in 1:nrepet)
-      isim[i] <- sum((lm.wfit(y = y, x = x[sample(nrow(x)), ], w = dudi1$lw)$fitted.values * wt)^2) / inertot
+      isim[i] <- sum((stats::lm.wfit(y = y, x = x[sample(nrow(x)), ], w = dudi1$lw)$fitted.values * wt)^2) / inertot
     return(as.randtest(sim = isim, obs = obs, call = match.call(), ...))
   }
 
