@@ -11,9 +11,9 @@
     dfxy <- data.frame(dfxy)
     if (length(z) != nrow(dfxy)) 
         stop(paste("Non equal row numbers", nrow(dfxy), length(z)))
-    opar <- par(mar = par("mar"))
-    on.exit(par(opar))
-    par(mar = c(0.1, 0.1, 0.1, 0.1))
+    opar <- graphics::par(mar = graphics::par("mar"))
+    on.exit(graphics::par(opar))
+    graphics::par(mar = c(0.1, 0.1, 0.1, 0.1))
     coo <- scatterutil.base(dfxy = dfxy, xax = xax, yax = yax, 
         xlim = xlim, ylim = ylim, grid = grid, addaxes = addaxes, 
         cgrid = cgrid, include.origin = include.origin, origin = origin, 
@@ -30,8 +30,8 @@
     }
     if (!is.null(neig)) {
         fun <- function(x, coo) {
-            segments(coo$x[x[1]], coo$y[x[1]], coo$x[x[2]], coo$y[x[2]], 
-                lwd = par("lwd") * cneig)
+            graphics::segments(coo$x[x[1]], coo$y[x[1]], coo$x[x[2]], coo$y[x[2]], 
+                lwd = graphics::par("lwd") * cneig)
         }
         apply(unclass(neig), 1, fun, coo = coo)
     }
@@ -40,32 +40,32 @@
     if (method == "greylevel") {
         br0 <- pretty(z, 6)
         nborn <- length(br0)
-        coeff <- diff(par("usr")[1:2])/15
+        coeff <- diff(graphics::par("usr")[1:2])/15
         numclass <- cut.default(z, br0, include.lowest = TRUE, labels = FALSE)
         valgris <- seq(1, 0, le = (nborn - 1))
         h <- csize * coeff
         for (i in 1:(nrow(dfxy))) {
-            symbols(coo$x[i], coo$y[i], squares = h, bg = gray(valgris[numclass[i]]), 
+            graphics::symbols(coo$x[i], coo$y[i], squares = h, bg = grDevices::gray(valgris[numclass[i]]), 
                 add = TRUE, inches = FALSE)
         }
         scatterutil.legend.square.grey(br0, valgris, h/2, clegend)
         if (cpoint > 0) 
-            points(coo$x, coo$y, pch = pch, cex = par("cex") * 
+            graphics::points(coo$x, coo$y, pch = pch, cex = graphics::par("cex") * 
                 cpoint)
     }
     else if (method == "squaresize") {
-        coeff <- diff(par("usr")[1:2])/15
+        coeff <- diff(graphics::par("usr")[1:2])/15
         sq <- sqrt(abs(z))
         if (is.null(zmax)) zmax <- max(abs(z))
         w1 <- sqrt(zmax)
         sq <- csize * coeff * sq/w1
         for (i in 1:(nrow(dfxy))) {
             if (sign(z[i]) >= 0) {
-                symbols(coo$x[i], coo$y[i], squares = sq[i],
+                graphics::symbols(coo$x[i], coo$y[i], squares = sq[i],
                     bg = "black", fg = "white", add = TRUE, inches = FALSE)
             }
             else {
-                symbols(coo$x[i], coo$y[i], squares = sq[i], 
+                graphics::symbols(coo$x[i], coo$y[i], squares = sq[i], 
                   bg = "white", fg = "black", add = TRUE, inches = FALSE)
             }
         }
@@ -78,12 +78,12 @@
         if (clegend > 0) 
             scatterutil.legend.bw.square(br0, sq0, sig0, clegend)
         if (cpoint > 0) 
-            points(coo$x, coo$y, pch = pch, cex = par("cex") * 
+            graphics::points(coo$x, coo$y, pch = pch, cex = graphics::par("cex") * 
                 cpoint)
     }
     else if (method == "circlesize") {
         print("not yet implemented")
     }
-    if (!add.plot) box()
+    if (!add.plot) graphics::box()
     invisible(match.call())
 }
