@@ -47,7 +47,7 @@
             area <- NULL
     }
     if ( !add.plot) 
-        plot.default(0, 0, type = "n", asp = 1, xlab = "", ylab = "", 
+        graphics::plot.default(0, 0, type = "n", asp = 1, xlab = "", ylab = "", 
         xaxt = "n", yaxt = "n", xlim = xlim, ylim = ylim, xaxs = "i", 
         yaxs = "i", frame.plot = FALSE)
 
@@ -56,13 +56,13 @@
     }
 
     if (!is.null(contour)) {
-        apply(contour, 1, function(x) segments(x[1], x[2], x[3], 
+        apply(contour, 1, function(x) graphics::segments(x[1], x[2], x[3], 
             x[4], lwd = 1))
     }
     if (grid & !add.plot) 
         scatterutil.grid(cgrid)
     if (addaxes & !add.plot) 
-        abline(h = 0, v = 0, lty = 1)
+        graphics::abline(h = 0, v = 0, lty = 1)
     if (!is.null(area)) {
         nlev <- nlevels(area[, 1])
         x1 <- area[, 2]
@@ -71,7 +71,7 @@
             lev <- levels(area[, 1])[i]
             a1 <- x1[area[, 1] == lev]
             a2 <- x2[area[, 1] == lev]
-            polygon(a1, a2)
+            graphics::polygon(a1, a2)
         }
     }
     if (csub > 0) 
@@ -99,28 +99,28 @@
                 break
             if (cref == 0) 
                 break
-            num <- chull(x1, y1)
+            num <- grDevices::chull(x1, y1)
             x2 <- x1[num]
             y2 <- y1[num]
             taux <- long/longinit
             if ((taux <= cref) & (cref == 1)) {
                 cref <- 0.75
                 if (any(optchull == 1)) 
-                  polygon(x2, y2, lty = 1, border=col[i])
+                  graphics::polygon(x2, y2, lty = 1, border=col[i])
             }
             if ((taux <= cref) & (cref == 0.75)) {
                 if (any(optchull == 0.75)) 
-                  polygon(x2, y2, lty = 5, border=col[i])
+                  graphics::polygon(x2, y2, lty = 5, border=col[i])
                 cref <- 0.5
             }
             if ((taux <= cref) & (cref == 0.5)) {
                 if (any(optchull == 0.5)) 
-                  polygon(x2, y2, lty = 3, border=col[i])
+                  graphics::polygon(x2, y2, lty = 3, border=col[i])
                 cref <- 0.25
             }
             if ((taux <= cref) & (cref == 0.25)) {
                 if (any(optchull == 0.25)) 
-                  polygon(x2, y2, lty = 2, border=col[i])
+                  graphics::polygon(x2, y2, lty = 2, border=col[i])
                 cref <- 0
             }
             x1 <- x1[-num]
@@ -134,9 +134,9 @@
 "scatterutil.eigen" <- function (w, nf = NULL, xmax = length(w), ymin=min(0,min(w)), ymax = max(w), wsel = 1, sub = "Eigenvalues",
     csub = 2, possub = "topright",box=FALSE,yaxt="n") 
 {
-    opar <- par(mar = par("mar"),plt=par("plt"))
-    on.exit(par(opar))
-    par(mar = c(0.8, 2.8, 0.8, 0.8),plt=par("plt"))
+    opar <- graphics::par(mar = graphics::par("mar"),plt=graphics::par("plt"))
+    on.exit(graphics::par(opar))
+    graphics::par(mar = c(0.8, 2.8, 0.8, 0.8),plt=graphics::par("plt"))
     if (length(w) < xmax) 
         w <- c(w, rep(0, xmax - length(w)))
     # modif by TJ to handle 3 colors (respented/kept/others)
@@ -144,9 +144,9 @@
     if(!is.null(nf)) {col.w[1:nf] <- "grey"}
     col.w[wsel] <- "black"
     #
-    barplot(w, col = col.w, ylim = c(ymin, ymax)*1.1,yaxt=yaxt)
+    graphics::barplot(w, col = col.w, ylim = c(ymin, ymax)*1.1,yaxt=yaxt)
     scatterutil.sub(cha = sub, csub = max(.8,csub), possub = possub)
-    if(box) box()
+    if(box) graphics::box()
 }
 
 ############ scatterutil.ellipse #################
@@ -231,12 +231,12 @@
     ell <- util.ellipse(m1, m2, v1, cxy, v2, cellipse)
     if (is.null(ell)) 
         return(invisible())
-    polygon(ell$x, ell$y, border=coul)
+    graphics::polygon(ell$x, ell$y, border=coul)
     if (axesell) 
-        segments(ell$seg1[1], ell$seg1[2], ell$seg1[3], ell$seg1[4], 
+        graphics::segments(ell$seg1[1], ell$seg1[2], ell$seg1[3], ell$seg1[4], 
             lty = 2, col=coul)
     if (axesell) 
-        segments(ell$seg2[1], ell$seg2[2], ell$seg2[3], ell$seg2[4], 
+        graphics::segments(ell$seg2[1], ell$seg2[2], ell$seg2[3], ell$seg2[4], 
             lty = 2, col=coul)
 }
 
@@ -256,10 +256,10 @@
     for (i in 1:(length(x))) {
         cha <- as.character(label[i])
         cha <- paste(" ", cha, " ", sep = "")
-        cex0 <- par("cex") * clabel
+        cex0 <- graphics::par("cex") * clabel
         
-        xh <- strwidth(cha, cex = cex0)
-        yh <- strheight(cha, cex = cex0) * 5/6
+        xh <- graphics::strwidth(cha, cex = cex0)
+        yh <- graphics::strheight(cha, cex = cex0) * 5/6
         if ((xref[i] > yref[i]) & (xref[i] > -yref[i])) {
             x1 <- x[i] + xh/2
             y1 <- y[i]
@@ -280,21 +280,21 @@
         # le bloc if(boxes) ne doit contenir que la fonction rect, sinon ca plante
         # si boxes = FALSE
         if (boxes) {
-            rect(x1 - xh/2, y1 - yh, x1 + xh/2, y1 + yh, col = "white", 
+            graphics::rect(x1 - xh/2, y1 - yh, x1 + xh/2, y1 + yh, col = "white", 
                 border = 1)
         }
-        text(x1, y1, cha, cex = cex0)
+        graphics::text(x1, y1, cha, cex = cex0)
     }
 }
 
 ############ scatterutil.eti #################
 "scatterutil.convrot90" <- function(xh,yh){
-  xusr <- par("usr")
+  xusr <- graphics::par("usr")
   tmp <- xh
-  xh <- yh/(xusr[4]-xusr[3])*par("pin")[2]
-  xh <- xh/ par("pin")[1] * (xusr[2]-xusr[1])
-  yh <- tmp/(xusr[2]-xusr[1])* par("pin")[1]
-  yh <- yh/ par("pin")[2] * (xusr[4]-xusr[3])
+  xh <- yh/(xusr[4]-xusr[3])*graphics::par("pin")[2]
+  xh <- xh/ graphics::par("pin")[1] * (xusr[2]-xusr[1])
+  yh <- tmp/(xusr[2]-xusr[1])* graphics::par("pin")[1]
+  yh <- yh/ graphics::par("pin")[2] * (xusr[4]-xusr[3])
   return(c(xh,yh))
 }
 
@@ -306,14 +306,14 @@
         return(invisible())
     if (any(label == "")) 
         return(invisible())
-    cex0 <- par("cex") * clabel
+    cex0 <- graphics::par("cex") * clabel
     for (i in 1:(length(x))) {
         cha <- as.character(label[i])
         cha <- paste(" ", cha, " ", sep = "")
         x1 <- x[i]
         y1 <- y[i]
-        xh <- strwidth(cha, cex = cex0)
-        yh <- strheight(cha, cex = cex0) * 5/3
+        xh <- graphics::strwidth(cha, cex = cex0)
+        yh <- graphics::strheight(cha, cex = cex0) * 5/3
         if(!horizontal){
           tmp <- scatterutil.convrot90(xh,yh)
           xh <- tmp[1]
@@ -321,13 +321,13 @@
                     
         }
         if (boxes) {
-            rect(x1 - xh/2, y1 - yh/2, x1 + xh/2, y1 + yh/2, 
+            graphics::rect(x1 - xh/2, y1 - yh/2, x1 + xh/2, y1 + yh/2, 
                  col = bg, border = coul[i])
           }
         if(horizontal){
-          text(x1, y1, cha, cex = cex0, col = coul[i])
+          graphics::text(x1, y1, cha, cex = cex0, col = coul[i])
         } else {
-          text(x1, y1, cha, cex = cex0, col = coul[i], srt = 90)
+          graphics::text(x1, y1, cha, cex = cex0, col = coul[i], srt = 90)
         }
         
     }
@@ -351,46 +351,46 @@
     ylim <- lim
   }
   
-  plot.default(0, 0, type = "n", xlab = "", ylab = "", xaxt = "n", 
+  graphics::plot.default(0, 0, type = "n", xlab = "", ylab = "", xaxt = "n", 
                yaxt = "n", xlim = xlim, ylim = ylim, xaxs = "i", yaxs = "i", 
                frame.plot = FALSE)
   
   if (grid) {
     if(horizontal){
-      axp <- par("xaxp")
+      axp <- graphics::par("xaxp")
     } else {
-      axp <- par("yaxp")
+      axp <- graphics::par("yaxp")
     }
     
     nline <- axp[3] + 1
     v0 <- seq(axp[1], axp[2], le = nline)
     if(horizontal){
-      segments(v0, rep(0, nline), v0, rep( 1, nline), col = gray(0.5), lty = 1)
-      segments(0, 0 , 0, 1, col = 1, lwd = 3)
+      graphics::segments(v0, rep(0, nline), v0, rep( 1, nline), col = grDevices::gray(0.5), lty = 1)
+      graphics::segments(0, 0 , 0, 1, col = 1, lwd = 3)
     } else {
-      segments(rep(0, nline), v0, rep( 1, nline), v0, col = gray(0.5), lty = 1)
-      segments(0, 0 , 1, 0, col = 1, lwd = 3)
+      graphics::segments(rep(0, nline), v0, rep( 1, nline), v0, col = grDevices::gray(0.5), lty = 1)
+      graphics::segments(0, 0 , 1, 0, col = 1, lwd = 3)
     }
     if (cgrid > 0) {
       a <- (axp[2] - axp[1])/axp[3]
       cha <- paste(" d = ", a," ",sep = "")
-      cex0 <- par("cex") * cgrid
-      xh <- strwidth(cha, cex = cex0)
-      yh <- strheight(cha, cex = cex0) * 5/3
-      x0 <- strwidth("  ", cex = cex0)
-      y0 <- strheight(" ", cex = cex0)/2
+      cex0 <- graphics::par("cex") * cgrid
+      xh <- graphics::strwidth(cha, cex = cex0)
+      yh <- graphics::strheight(cha, cex = cex0) * 5/3
+      x0 <- graphics::strwidth("  ", cex = cex0)
+      y0 <- graphics::strheight(" ", cex = cex0)/2
       if(horizontal){
         if(reverse){
-          x1 <- par("usr")[1]
-          y1 <- par("usr")[4]
-          rect(x1 + x0, y1 - y0 -yh, x1 + xh + x0, y1 - y0, col = "white", border = "white")
-          text(x1 + xh/2 + x0, y1 - yh/2 - y0, cha, cex = cex0)
+          x1 <- graphics::par("usr")[1]
+          y1 <- graphics::par("usr")[4]
+          graphics::rect(x1 + x0, y1 - y0 -yh, x1 + xh + x0, y1 - y0, col = "white", border = "white")
+          graphics::text(x1 + xh/2 + x0, y1 - yh/2 - y0, cha, cex = cex0)
           
         } else {
-          x1 <- par("usr")[1]
-          y1 <- par("usr")[3]
-          rect(x1 + x0, y1 + y0, x1 + xh + x0, y1 + yh + y0, col = "white", border = "white")
-          text(x1 + xh/2 + x0, y1 + yh/2 + y0, cha, cex = cex0)
+          x1 <- graphics::par("usr")[1]
+          y1 <- graphics::par("usr")[3]
+          graphics::rect(x1 + x0, y1 + y0, x1 + xh + x0, y1 + yh + y0, col = "white", border = "white")
+          graphics::text(x1 + xh/2 + x0, y1 + yh/2 + y0, cha, cex = cex0)
         }
       } else {
         
@@ -401,22 +401,22 @@
         x0 <- tmp[1]
         y0 <- tmp[2]
         if(reverse) {
-          x1 <- par("usr")[2]
-          y1 <- par("usr")[4]
-          rect(x1 - x0 - xh, y1 - y0 - yh, x1  - x0, y1 -  y0, col = "white", border = "white")
-          text(x1 - xh/2 - x0, y1 - yh/2 - y0, cha, cex = cex0, srt=270)          
+          x1 <- graphics::par("usr")[2]
+          y1 <- graphics::par("usr")[4]
+          graphics::rect(x1 - x0 - xh, y1 - y0 - yh, x1  - x0, y1 -  y0, col = "white", border = "white")
+          graphics::text(x1 - xh/2 - x0, y1 - yh/2 - y0, cha, cex = cex0, srt=270)          
         } else {
-          x1 <- par("usr")[1]
-          y1 <- par("usr")[4]
-          rect(x1 + x0, y1 - y0 - yh, x1 + xh + x0, y1 -  y0, col = "white", border = "white")
-          text(x1 + xh/2 + x0, y1 - yh/2 - y0, cha, cex = cex0, srt=90)
+          x1 <- graphics::par("usr")[1]
+          y1 <- graphics::par("usr")[4]
+          graphics::rect(x1 + x0, y1 - y0 - yh, x1 + xh + x0, y1 -  y0, col = "white", border = "white")
+          graphics::text(x1 + xh/2 + x0, y1 - yh/2 - y0, cha, cex = cex0, srt=90)
         }
       }
     }
   }
   
   href <- max(3, 2 * cgrid, 2 * csub)
-  href <- strheight("A", cex = par("cex") * href)
+  href <- graphics::strheight("A", cex = graphics::par("cex") * href)
   if(!horizontal){
     tmp <- scatterutil.convrot90(0,href)
     href <- tmp[1]
@@ -425,25 +425,25 @@
   
   if (csub > 0) {
     cha <- as.character(sub)
-    y1 <- par("usr")[3] + href/2
+    y1 <- graphics::par("usr")[3] + href/2
     if (all(c(length(cha) > 0, !is.null(cha), !is.na(cha), cha != ""))) {
       cha <- paste(" ",cha," ",sep="")
-      cex0 <- par("cex") * csub
-      xh <- strwidth(cha, cex = cex0)
-      yh <- strheight(cha, cex = cex0) *5/3
-      x0 <- strwidth(" ", cex = cex0)/2
-      y0 <- strheight(" ", cex = cex0)/2
+      cex0 <- graphics::par("cex") * csub
+      xh <- graphics::strwidth(cha, cex = cex0)
+      yh <- graphics::strheight(cha, cex = cex0) *5/3
+      x0 <- graphics::strwidth(" ", cex = cex0)/2
+      y0 <- graphics::strheight(" ", cex = cex0)/2
       if(horizontal){
         if(reverse) {
-          x1 <- par("usr")[2]
-          y1 <- par("usr")[4]
-          rect(x1 - x0 - xh, y1 - y0 -yh, x1 -x0, y1 - y0, col = "white", border = "white")
-          text(x1 - xh/2 - x0, y1 - yh/2 - y0, cha, cex = cex0)
+          x1 <- graphics::par("usr")[2]
+          y1 <- graphics::par("usr")[4]
+          graphics::rect(x1 - x0 - xh, y1 - y0 -yh, x1 -x0, y1 - y0, col = "white", border = "white")
+          graphics::text(x1 - xh/2 - x0, y1 - yh/2 - y0, cha, cex = cex0)
         } else {
-          x1 <- par("usr")[2]
-          y1 <- par("usr")[3]
-          rect(x1 - x0 - xh, y1 + y0, x1 -x0, y1 + yh + y0, col = "white", border = "white")
-          text(x1 - xh/2 - x0, y1 + yh/2 + y0, cha, cex = cex0)
+          x1 <- graphics::par("usr")[2]
+          y1 <- graphics::par("usr")[3]
+          graphics::rect(x1 - x0 - xh, y1 + y0, x1 -x0, y1 + yh + y0, col = "white", border = "white")
+          graphics::text(x1 - xh/2 - x0, y1 + yh/2 + y0, cha, cex = cex0)
         }
       } else {
         tmp <- scatterutil.convrot90(xh,yh)
@@ -453,36 +453,36 @@
         x0 <- tmp[1]
         y0 <- tmp[2]
         if(reverse) {
-          x1 <- par("usr")[2]
-          y1 <- par("usr")[3]
-          rect(x1 - x0 - xh, y1 + y0, x1 - x0 , y1 + yh + y0, col = "white", border = "white")
-          text(x1 - xh/2 - x0, y1 + yh/2 + y0, cha, cex = cex0,srt=270)
+          x1 <- graphics::par("usr")[2]
+          y1 <- graphics::par("usr")[3]
+          graphics::rect(x1 - x0 - xh, y1 + y0, x1 - x0 , y1 + yh + y0, col = "white", border = "white")
+          graphics::text(x1 - xh/2 - x0, y1 + yh/2 + y0, cha, cex = cex0,srt=270)
  
         } else {
-          x1 <- par("usr")[1]
-          y1 <- par("usr")[3]
-          rect(x1 + x0, y1 + y0, x1 + x0 + xh, y1 + yh + y0, col = "white", border = "white")
-          text(x1 + xh/2 + x0, y1 + yh/2 + y0, cha, cex = cex0,srt=90)
+          x1 <- graphics::par("usr")[1]
+          y1 <- graphics::par("usr")[3]
+          graphics::rect(x1 + x0, y1 + y0, x1 + x0 + xh, y1 + yh + y0, col = "white", border = "white")
+          graphics::text(x1 + xh/2 + x0, y1 + yh/2 + y0, cha, cex = cex0,srt=90)
         }
       }
       
     }
   }
-  box()
+  graphics::box()
   if(horizontal){
     if(reverse){
-      abline( h = par("usr")[4] - href)
+      graphics::abline( h = graphics::par("usr")[4] - href)
     } else {
-      abline( h = par("usr")[3] + href)
+      graphics::abline( h = graphics::par("usr")[3] + href)
     }
-    return(c(min = par("usr")[1] , max = par("usr")[2], href = href))
+    return(c(min = graphics::par("usr")[1] , max = graphics::par("usr")[2], href = href))
   } else {
     if(reverse) {
-      abline( v = par("usr")[2] - href)
+      graphics::abline( v = graphics::par("usr")[2] - href)
     } else {
-      abline( v = par("usr")[1] + href)
+      graphics::abline( v = graphics::par("usr")[1] + href)
     }
-    return(c(min = par("usr")[3] , max = par("usr")[4], href = href))
+    return(c(min = graphics::par("usr")[3] , max = graphics::par("usr")[4], href = href))
   }
   
 }
@@ -492,25 +492,25 @@
 "scatterutil.grid" <- function (cgrid) {
     col <- "lightgray"
     lty <- 1
-    xaxp <- par("xaxp")
+    xaxp <- graphics::par("xaxp")
     ax <- (xaxp[2] - xaxp[1])/xaxp[3]
-    yaxp <- par("yaxp")
+    yaxp <- graphics::par("yaxp")
     ay <- (yaxp[2] - yaxp[1])/yaxp[3]
     a <- min(ax, ay)
     v0 <- seq(xaxp[1], xaxp[2], by = a)
     h0 <- seq(yaxp[1], yaxp[2], by = a)
-    abline(v = v0, col = col, lty = lty)
-    abline(h = h0, col = col, lty = lty)
+    graphics::abline(v = v0, col = col, lty = lty)
+    graphics::abline(h = h0, col = col, lty = lty)
     if (cgrid <= 0) 
         return(invisible())
     cha <- paste(" d = ", a, " ", sep = "")
-    cex0 <- par("cex") * cgrid
-    xh <- strwidth(cha, cex = cex0)
-    yh <- strheight(cha, cex = cex0) * 5/3
-    x1 <- par("usr")[2]
-    y1 <- par("usr")[4]
-    rect(x1 - xh, y1 - yh, x1 + xh, y1 + yh, col = "white", border = 0)
-    text(x1 - xh/2, y1 - yh/2, cha, cex = cex0)
+    cex0 <- graphics::par("cex") * cgrid
+    xh <- graphics::strwidth(cha, cex = cex0)
+    yh <- graphics::strheight(cha, cex = cex0) * 5/3
+    x1 <- graphics::par("usr")[2]
+    y1 <- graphics::par("usr")[4]
+    graphics::rect(x1 - xh, y1 - yh, x1 + xh, y1 + yh, col = "white", border = 0)
+    graphics::text(x1 - xh/2, y1 - yh/2, cha, cex = cex0)
 }
 
 ############ scatterutil.legend.bw.square #################
@@ -518,25 +518,25 @@
     br0 <- round(br0, digits = 6)
     cha <- as.character(br0[1])
     for (i in (2:(length(br0)))) cha <- paste(cha, br0[i], sep = " ")
-    cex0 <- par("cex") * clegend
-    yh <- max(c(strheight(cha, cex = cex0), sq0))
-    h <- strheight(cha, cex = cex0)
-    y0 <- par("usr")[3] + yh/2 + h/2
-    ltot <- strwidth(cha, cex = cex0) + sum(sq0) + h
-    rect(par("usr")[1] + h/4, y0 - yh/2 - h/4, par("usr")[1] + 
+    cex0 <- graphics::par("cex") * clegend
+    yh <- max(c(graphics::strheight(cha, cex = cex0), sq0))
+    h <- graphics::strheight(cha, cex = cex0)
+    y0 <- graphics::par("usr")[3] + yh/2 + h/2
+    ltot <- graphics::strwidth(cha, cex = cex0) + sum(sq0) + h
+    graphics::rect(graphics::par("usr")[1] + h/4, y0 - yh/2 - h/4, graphics::par("usr")[1] + 
         ltot + h/4, y0 + yh/2 + h/4, col = "white")
-    x0 <- par("usr")[1] + h/2
+    x0 <- graphics::par("usr")[1] + h/2
     for (i in (1:(length(sq0)))) {
         cha <- br0[i]
         cha <- paste(" ", cha, sep = "")
-        xh <- strwidth(cha, cex = cex0)
-        text(x0 + xh/2, y0, cha, cex = cex0)
+        xh <- graphics::strwidth(cha, cex = cex0)
+        graphics::text(x0 + xh/2, y0, cha, cex = cex0)
         z0 <- sq0[i]
         x0 <- x0 + xh + z0/2
         if (sig0[i] >= 0) 
-            symbols(x0, y0, squares = z0, bg = "black", fg = "white", 
+            graphics::symbols(x0, y0, squares = z0, bg = "black", fg = "white", 
                 add = TRUE, inches = FALSE)
-        else symbols(x0, y0, squares = z0, bg = "white", fg = "black", 
+        else graphics::symbols(x0, y0, squares = z0, bg = "white", fg = "black", 
             add = TRUE, inches = FALSE)
         x0 <- x0 + z0/2
     }
@@ -549,35 +549,35 @@
         return(invisible())
     br0 <- round(br0, digits = 6)
     nborn <- length(br0)
-    cex0 <- par("cex") * clegend
-    x0 <- par("usr")[1] + h
+    cex0 <- graphics::par("cex") * clegend
+    x0 <- graphics::par("usr")[1] + h
     x1 <- x0
     for (i in (2:(nborn))) {
         x1 <- x1 + h
         cha <- br0[i]
         cha <- paste(cha, "]", sep = "")
-        xh <- strwidth(cha, cex = cex0)
+        xh <- graphics::strwidth(cha, cex = cex0)
         if (i == (nborn)) 
             break
         x1 <- x1 + xh + h
     }
-    yh <- max(strheight(paste(br0), cex = cex0), h)
-    y0 <- par("usr")[3] + yh/2 + h/2
-    rect(par("usr")[1] + h/4, y0 - yh/2 - h/4, x1 - h/4, y0 + 
+    yh <- max(graphics::strheight(paste(br0), cex = cex0), h)
+    y0 <- graphics::par("usr")[3] + yh/2 + h/2
+    graphics::rect(graphics::par("usr")[1] + h/4, y0 - yh/2 - h/4, x1 - h/4, y0 + 
         yh/2 + h/4, col = "white")
-    x0 <- par("usr")[1] + h
+    x0 <- graphics::par("usr")[1] + h
     for (i in (2:(nborn))) {
-        symbols(x0, y0, squares = h, bg = gray(valgris[i - 1]), 
+        graphics::symbols(x0, y0, squares = h, bg = grDevices::gray(valgris[i - 1]), 
             add = TRUE, inches = FALSE)
         x0 <- x0 + h
         cha <- br0[i]
         if (cha < 1e-05) 
             cha <- round(cha, digits = 3)
         cha <- paste(cha, "]", sep = "")
-        xh <- strwidth(cha, cex = cex0)
+        xh <- graphics::strwidth(cha, cex = cex0)
         if (i == (nborn)) 
             break
-        text(x0 + xh/2, y0, cha, cex = cex0)
+        graphics::text(x0 + xh/2, y0, cha, cex = cex0)
         x0 <- x0 + xh + h
     }
     invisible()
@@ -594,21 +594,21 @@
         l0 <- 10
     h0 <- 1/(l0 + 1)
     mid0 <- seq(h0/2, 1 - h0/2, le = l0 + 1)
-    qq <- quantile(w, seq(0, 1, le = l0 + 1))
+    qq <- stats::quantile(w, seq(0, 1, le = l0 + 1))
     w0 <- as.numeric(cut(w, br = qq, inc = TRUE))
     w0 <- seq(0, 1, le = l0)[w0]
-    opar <- par(new = par("new"), mar = par("mar"), usr = par("usr"))
-    on.exit(par(opar))
-    par(new = TRUE)
-    par(mar = c(0.1, 0.1, 0.1, 0.1))
-    plot(0, 0, type = "n", xlab = "", ylab = "", xaxt = "n", 
+    opar <- graphics::par(new = graphics::par("new"), mar = graphics::par("mar"), usr = graphics::par("usr"))
+    on.exit(graphics::par(opar))
+    graphics::par(new = TRUE)
+    graphics::par(mar = c(0.1, 0.1, 0.1, 0.1))
+    graphics::plot(0, 0, type = "n", xlab = "", ylab = "", xaxt = "n", 
         yaxt = "n", xlim = c(0, 2), ylim = c(0, 1.5))
-    rect(rep(0, l0), seq(h0/2, by = h0, le = l0), rep(h0, l0), 
-        seq(3 * h0/2, by = h0, le = l0), col = gray(seq(1, 0, 
+    graphics::rect(rep(0, l0), seq(h0/2, by = h0, le = l0), rep(h0, l0), 
+        seq(3 * h0/2, by = h0, le = l0), col = grDevices::gray(seq(1, 0, 
             le = l0)))
-    text(rep(h0, 9), mid0, as.character(signif(qq, digits = 2)), 
-        pos = 4, cex = par("cex") * clegend)
-    box(col = "white")
+    graphics::text(rep(h0, 9), mid0, as.character(signif(qq, digits = 2)), 
+        pos = 4, cex = graphics::par("cex") * clegend)
+    graphics::box(col = "white")
 }
 
 ############ scatterutil.scaling #################
@@ -639,7 +639,7 @@
     for (i in which(z > 0)) {
         hx <- cstar * (x[i] - x1)
         hy <- cstar * (y[i] - y1)
-        segments(x1, y1, x1 + hx, y1 + hy, col=coul)
+        graphics::segments(x1, y1, x1 + hx, y1 + hy, col=coul)
     }
 }
 
@@ -657,33 +657,33 @@
         return(invisible())
     if (csub == 0) 
         return(invisible())
-    cex0 <- par("cex") * csub
+    cex0 <- graphics::par("cex") * csub
     cha <- paste(" ", cha, " ", sep = "")
-    xh <- strwidth(cha, cex = cex0)
-    yh <- strheight(cha, cex = cex0) * 5/3
+    xh <- graphics::strwidth(cha, cex = cex0)
+    yh <- graphics::strheight(cha, cex = cex0) * 5/3
     if (possub == "bottomleft") {
-        x1 <- par("usr")[1]
-        y1 <- par("usr")[3]
-        rect(x1, y1, x1 + xh, y1 + yh, col = "white", border = 0)
-        text(x1 + xh/2, y1 + yh/2, cha, cex = cex0)
+        x1 <- graphics::par("usr")[1]
+        y1 <- graphics::par("usr")[3]
+        graphics::rect(x1, y1, x1 + xh, y1 + yh, col = "white", border = 0)
+        graphics::text(x1 + xh/2, y1 + yh/2, cha, cex = cex0)
     }
     else if (possub == "topleft") {
-        x1 <- par("usr")[1]
-        y1 <- par("usr")[4]
-        rect(x1, y1, x1 + xh, y1 - yh, col = "white", border = 0)
-        text(x1 + xh/2, y1 - yh/2, cha, cex = cex0)
+        x1 <- graphics::par("usr")[1]
+        y1 <- graphics::par("usr")[4]
+        graphics::rect(x1, y1, x1 + xh, y1 - yh, col = "white", border = 0)
+        graphics::text(x1 + xh/2, y1 - yh/2, cha, cex = cex0)
     }
     else if (possub == "bottomright") {
-        x1 <- par("usr")[2]
-        y1 <- par("usr")[3]
-        rect(x1, y1, x1 - xh, y1 + yh, col = "white", border = 0)
-        text(x1 - xh/2, y1 + yh/2, cha, cex = cex0)
+        x1 <- graphics::par("usr")[2]
+        y1 <- graphics::par("usr")[3]
+        graphics::rect(x1, y1, x1 - xh, y1 + yh, col = "white", border = 0)
+        graphics::text(x1 - xh/2, y1 + yh/2, cha, cex = cex0)
     }
     else if (possub == "topright") {
-        x1 <- par("usr")[2]
-        y1 <- par("usr")[4]
-        rect(x1, y1, x1 - xh, y1 - yh, col = "white", border = 0)
-        text(x1 - xh/2, y1 - yh/2, cha, cex = cex0)
+        x1 <- graphics::par("usr")[2]
+        y1 <- graphics::par("usr")[4]
+        graphics::rect(x1, y1, x1 - xh, y1 - yh, col = "white", border = 0)
+        graphics::text(x1 - xh/2, y1 - yh/2, cha, cex = cex0)
     }
 }
 
