@@ -7,25 +7,25 @@
         xax <- 1
     if ((xax < 1) || (xax > x$nf)) 
         stop("non convenient axe number")
-    def.par <- par(no.readonly = TRUE)
-    on.exit(par(def.par))
+    def.par <- graphics::par(no.readonly = TRUE)
+    on.exit(graphics::par(def.par))
     oritab <- eval.parent(as.list(x$call)[[2]])
     nvar <- ncol(oritab)
     if (is.null(which.var)) 
         which.var <- (1:nvar)
     if (is.null(mfrow)) 
-        mfrow <- n2mfrow(length(which.var))
-    par(mfrow = mfrow)
-    if (prod(par("mfrow")) < length(which.var)) 
-        par(ask = TRUE)
-    par(mar = c(2.6, 2.6, 1.1, 1.1))
+        mfrow <- grDevices::n2mfrow(length(which.var))
+    graphics::par(mfrow = mfrow)
+    if (prod(graphics::par("mfrow")) < length(which.var)) 
+        graphics::par(ask = TRUE)
+    graphics::par(mar = c(2.6, 2.6, 1.1, 1.1))
     score <- x$l1[, xax]
     for (i in which.var) {
         y <- oritab[, i]
-        plot(score, y, type = "n")
-        points(score, y, pch = 20)
+        graphics::plot(score, y, type = "n")
+        graphics::points(score, y, pch = 20)
         if (abline) 
-            abline(lm(y ~ score))
+            graphics::abline(stats::lm(y ~ score))
         scatterutil.sub(sub[i], csub = csub, "topleft")
     }
 }
